from distutils.core import setup

setup(
    name='gsnester',
    version='1.4.0',
    py_modules = ['gsnester'],
    author = 'Geetika Sharma',
    author_email = 'geetusharma7@gmail.com',
    description = 'Simple printer for nested lists',
    long_description='This is gsnester.py module, and it provides one function called print_nested_lists() which prints lists that may or may not include nested list'
    )
